@@ -18,6 +18,9 @@ import time
 
 from sphinx.util import logging
 
+from . import version
+
+
 LOG = logging.getLogger(__name__)
 
 _timeint = int(os.environ.get('SOURCE_DATE_EPOCH', time.time()))
@@ -48,7 +51,7 @@ def _get_last_updated_file(src_file):
             try:
                 return datetime.datetime.strptime(last_updated_t,
                                                   '%Y-%m-%d %H:%M:%S')
-            except ValueError as err:
+            except ValueError:
                 LOG.info(
                     '[openstackdocstheme] '
                     'Could not parse modification time of %s: %r',
@@ -81,9 +84,13 @@ def _get_last_updated(app, pagename):
                 '[openstackdocstheme] Last updated for %s is %s',
                 pagename, last_updated)
             return last_updated
-    LOG.info(
-        '[openstackdocstheme] could not determine last_updated for %r',
-        pagename)
+
+    if pagename not in ('genindex', 'search'):
+        LOG.info(
+            '[openstackdocstheme] could not determine last_updated for %r',
+            pagename,
+        )
+
     return _default_last_updated
 
 
@@ -98,4 +105,6 @@ def setup(app):
     app.connect('html-page-context', html_page_context)
     return {
         'parallel_read_safe': True,
+        'parallel_write_safe': True,
+        'version': version.version_info.version_string(),
     }
